==> openjdk-src-11.0.1.u13-2-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ksh.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ksh extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "de vereineschte arraabesche Emiraate ier Dirham" },
            { "afn", "Afjahni" },
            { "all", "albaanesche Lek" },
            { "amd", "armeenesche Dram" },
            { "ang", "neederl\u00e4ngsch antillesche Jullde" },
            { "aoa", "angjolaanesche Kwansa" },
            { "ars", "ajentiinesche Peeso" },
            { "aud", "austraalesche Dollaa" },
            { "awg", "arubesche Florin" },
            { "azm", "Asserbaidschaani Manat (1993\u20132006)" },
            { "azn", "Asserbaidschaani Manat" },
            { "bam", "\u00f6mtuuschbaa Mark us Bo\u00dfnije un d\u00e4 H\u00e4chejovvina" },
            { "bbd", "Barbados-Dollaa" },
            { "bdt", "Taka us Banglad\u00e4sch" },
            { "bgn", "buljaaresche Lev" },
            { "bhd", "Bachrainesche Denaa" },
            { "bif", "burundesche Frang" },
            { "bmd", "Bermuuda-Dollaa" },
            { "bnd", "Brunei-Dollaa" },
            { "bob", "Bollivijano" },
            { "brl", "brasilljaanesche Real" },
            { "bsd", "bahama\u2019sche Dollaa" },
            { "btn", "bhutanesesche Ngultrum" },
            { "bwp", "Pula us Bozwaana" },
            { "byn", "wii\u00dfru\u00dfesche Rubel" },
            { "byr", "wii\u00dfru\u00dfesche Rubel (2000\u20132016)" },
            { "bzd", "belizjaanesche Dollaa" },
            { "cad", "kannaadesche Dollaa" },
            { "cdf", "kongjoleesesche Frang" },
            { "chf", "schweijzer Fr\u00e4nkli" },
            { "clp", "schileenesche Peeso" },
            { "cny", "schineesesche Yuan Renminbi" },
            { "cop", "kolumbesche Peso" },
            { "crc", "ko\u00dftarikaanesche Col\u00f3n" },
            { "cuc", "\u00f6mtuuschbaa kubaanesche Pesos" },
            { "cup", "kubaanesche Peesos" },
            { "cve", "kapverdesche Eskuudos" },
            { "czk", "tsch\u00e4schesche Kruhne" },
            { "djf", "Frang u\u00df Dschibuti" },
            { "dkk", "d\u00e4nesche Kruhne" },
            { "dop", "dommenikaanesche Peesos" },
            { "dzd", "aljeresche Denaa" },
            { "eek", "\u00c4\u00dfnesche Kruhne" },
            { "egp", "\u00e4jiptesche Pongk" },
            { "ern", "Nafka u\u00df Erritreja" },
            { "etb", "\u00e4tejoopesche Birr" },
            { "eur", "Euro" },
            { "fjd", "Fidschi-Dollaa" },
            { "fkp", "Pongk vun de Falkland-Enselle" },
            { "gbp", "brittesche \u00a3" },
            { "gel", "jeorjesche Lari" },
            { "ghs", "janaaesche Cedi" },
            { "gip", "jibraltaa\u2019sche Pongk" },
            { "gmd", "jambesche Dalasi" },
            { "gnf", "Jineea-Frang" },
            { "gtq", "juatemalesche Quetzal" },
            { "gyd", "Juaana-Dollaa" },
            { "hkd", "Hongkong-Dollaa" },
            { "hnl", "hondureanesche Lempira" },
            { "hrk", "krowaatesche Kuna" },
            { "htg", "haiitesche Gourde" },
            { "huf", "unjarresche Forint" },
            { "idr", "indoneesesche Ruupije" },
            { "ils", "i\u00dfraeelesche Schekel" },
            { "inr", "indesche Ruupije" },
            { "iqd", "iraakesche Denaa" },
            { "irr", "persesche Rial" },
            { "isk", "i\u00dfl\u00e4ndesche Kruhne" },
            { "jmd", "jamaikaanesche Dollaa" },
            { "jod", "Jordaanesche Dollaa" },
            { "jpy", "japaanesche Jen" },
            { "kes", "Kenjaanesche Schillinge" },
            { "kgs", "kirjiisesche Som" },
            { "khr", "kambodschaanesche Riel" },
            { "kmf", "kommooresche Frang" },
            { "kpw", "noodkorejaansche Won" },
            { "krw", "s\u00f6\u00f6dkorejaansche Won" },
            { "kwd", "kuwaitesche Denaa" },
            { "kyd", "Kaimann-Dollaa" },
            { "kzt", "kasakesche Tenge" },
            { "lak", "loaatesche Kip" },
            { "lbp", "libaneesesche Pongk" },
            { "lkr", "schrilankesche Ruupije" },
            { "lrd", "liberijaanesche Dollaa" },
            { "lsl", "lesoothesche Loti" },
            { "ltl", "littouesche Litas" },
            { "lvl", "l\u00e4ttesche Lats" },
            { "lyd", "libesche Denaa" },
            { "mad", "marrokaanesche Dirhamm" },
            { "mdl", "moldaavesche Leu" },
            { "mga", "madajaskesche Ariary" },
            { "mkd", "mazedoonesche Denaa" },
            { "mmk", "burmeesesche Kyat" },
            { "mnt", "mongjoolesche Tugrik" },
            { "mop", "makaneesesche Pataca" },
            { "mro", "mauretanesche Ouguiya (1973\u20132017)" },
            { "mru", "mauretanesche Ouguiya" },
            { "mur", "maurizjahnesche Ruupije" },
            { "mvr", "mallediivesche Rufiyaa" },
            { "mwk", "malaawesche Kwache" },
            { "mxn", "mexekaanesche Peeso" },
            { "myr", "malaisesche Ringgit" },
            { "mzm", "mosambikaanesche Metical (1980\u20132006)" },
            { "mzn", "mossambikaanesche Metical" },
            { "nad", "namiibesche Dollaa" },
            { "ngn", "nijerijaanesche Naira" },
            { "nio", "nikarajaanesche C\u00f3rdoba" },
            { "nok", "norrweejesche Kruhne" },
            { "npr", "nepaleesesche Ruupije" },
            { "nzd", "neuseel\u00e4ndesche Dollaa" },
            { "omr", "ommaanesche Rijal" },
            { "pab", "pannameesesche Balboa" },
            { "pen", "perruaanesche Sol" },
            { "pgk", "papua neujinejaanesche Kina" },
            { "php", "fillipiinesche Pesos" },
            { "pkr", "pakestaanesche Ruupije" },
            { "pln", "polnesche Z\u0142oty" },
            { "pyg", "parajuaanesche Juarani" },
            { "qar", "kataaresche Rijal" },
            { "rol", "rom\u00e4\u00e4nesche Leu (1952\u20132006)" },
            { "ron", "rom\u00e4\u00e4nesche Leu" },
            { "rsd", "s\u00e4rbesche Denaare" },
            { "rub", "russesche Ruubel" },
            { "rwf", "ruandesche Frang" },
            { "sar", "saudesche Rijal" },
            { "sbd", "solomonesche Dollaa" },
            { "scr", "seischellesche Ruupije" },
            { "sdg", "sudaneesesche Pongk" },
            { "sek", "schweedesche Kruhne" },
            { "sgd", "singjapurejaanesche Dollaa" },
            { "shp", "Zint-Hellena-Pongk" },
            { "skk", "\u00dflovaakesche Kruhne" },
            { "sll", "\u1e9ej\u00e4rra-lejoneesesche Leone" },
            { "sos", "somaalesche Schillenge" },
            { "srd", "s\u00fcrinameesesche Dollaa" },
            { "ssp", "s\u00f6dsudaneesesche Pongk" },
            { "std", "Dobra vun S\u00e3o Tom\u00e9 un Pr\u00edncipe (1977\u20132017)" },
            { "stn", "Dobra vun S\u00e3o Tom\u00e9 un Pr\u00edncipe" },
            { "svc", "asalvadorejaanesche Cosan" },
            { "syp", "s\u00fc\u00fcresche Pund" },
            { "szl", "swasil\u00e4ndesche Lilangeni" },
            { "thb", "tail\u00e4ndesche Baht" },
            { "tjs", "tadschiki\u00dftaanesche Somoni" },
            { "tmm", "turkmene\u00dftaanesche Manat (1993\u20132009)" },
            { "tmt", "turkmene\u00dftaanesche Manat" },
            { "tnd", "tuneesesche Denaa" },
            { "top", "tongjanes Pa\u02bbangache" },
            { "try", "t\u00f6rkesche Liire" },
            { "ttd", "Dollaa u\u00df Trinidad un Tob\u00e4\u00e4jo" },
            { "twd", "neu taiwaneesesche Dollaa" },
            { "tzs", "tansaanesche Schillenge" },
            { "uah", "ukraijnesche Hryvnia" },
            { "ugx", "ujandesche Schillenge" },
            { "usd", "amm\u00e4rrikaanesche Dollaa" },
            { "uyu", "urrujuwaische Peeso" },
            { "uzs", "u\u00dfbeekesche Som" },
            { "vef", "venezuelaanesche Bol\u00edvar" },
            { "vnd", "vij\u00e4tnammeesesche Dong" },
            { "vuv", "vanuatesche Vatu" },
            { "wst", "samowaanesche Tala" },
            { "xaf", "Kmmeruhner Frang" },
            { "xag", "Sellver" },
            { "xau", "Jold" },
            { "xcd", "o\u00df-karribbesche Dollaa" },
            { "xfo", "franz\u00fc\u00fcsesche Joldfranke" },
            { "xof", "Frang u\u00df de \u00c4lfebeink\u00f6\u00df" },
            { "xpd", "Palladijum" },
            { "xpf", "polineesesche Frang" },
            { "xpt", "Plaatin" },
            { "xts", "W\u00e4hrong zum Pr\u00f6\u00f6fe" },
            { "xxx", "onbikannte W\u00e4hrong" },
            { "yer", "jemenitesche Rijal" },
            { "zar", "s\u00f6daffrekaanesche Rand" },
            { "zmk", "sambesche Kwacha (1968\u20132012)" },
            { "zmw", "sambesche Kwacha" },
            { "zwd", "simbabwesche Dollaa (1980\u20132008)" },
            { "zwl", "simbabwesche Dollaa (2009)" },
        };
        return data;
    }
}

==> openjdk-src-15.0.1.u9-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_ksh.java <==
/*
 * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_ksh extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "de vereineschte arraabesche Emiraate ier Dirham" },
            { "afn", "Afjahni" },
            { "all", "albaanesche Lek" },
            { "amd", "armeenesche Dram" },
            { "ang", "neederl\u00e4ngsch antillesche Jullde" },
            { "aoa", "angjolaanesche Kwansa" },
            { "ars", "ajentiinesche Peeso" },
            { "aud", "austraalesche Dollaa" },
            { "awg", "arubesche Florin" },
            { "azm", "Asserbaidschaani Manat (1993\u20132006)" },
            { "azn", "Asserbaidschaani Manat" },
            { "bam", "\u00f6mtuuschbaa Mark us Bo\u00dfnije un d\u00e4 H\u00e4chejovvina" },
            { "bbd", "Barbados-Dollaa" },
            { "bdt", "Taka us Banglad\u00e4sch" },
            { "bgn", "buljaaresche Lev" },
            { "bhd", "Bachrainesche Denaa" },
            { "bif", "burundesche Frang" },
            { "bmd", "Bermuuda-Dollaa" },
            { "bnd", "Brunei-Dollaa" },
            { "bob", "Bollivijano" },
            { "brl", "brasilljaanesche Real" },
            { "bsd", "bahama\u2019sche Dollaa" },
            { "btn", "bhutanesesche Ngultrum" },
            { "bwp", "Pula us Bozwaana" },
            { "byn", "wii\u00dfru\u00dfesche Rubel" },
            { "byr", "wii\u00dfru\u00dfesche Rubel (2000\u20132016)" },
            { "bzd", "belizjaanesche Dollaa" },
            { "cad", "kannaadesche Dollaa" },
            { "cdf", "kongjoleesesche Frang" },
            { "chf", "schweijzer Fr\u00e4nkli" },
            { "clp", "schileenesche Peeso" },
            { "cny", "schineesesche Yuan Renminbi" },
            { "cop", "kolumbesche Peso" },
            { "crc", "ko\u00dftarikaanesche Col\u00f3n" },
            { "cuc", "\u00f6mtuuschbaa kubaanesche Pesos" },
            { "cup", "kubaanesche Peesos" },
            { "cve", "kapverdesche Eskuudos" },
            { "czk", "tsch\u00e4schesche Kruhne" },
            { "djf", "Frang u\u00df Dschibuti" },
            { "dkk", "d\u00e4nesche Kruhne" },
            { "dop", "dommenikaanesche Peesos" },
            { "dzd", "aljeresche Denaa" },
            { "eek", "\u00c4\u00dfnesche Kruhne" },
            { "egp", "\u00e4jiptesche Pongk" },
            { "ern", "Nafka u\u00df Erritreja" },
            { "etb", "\u00e4tejoopesche Birr" },
            { "eur", "Euro" },
            { "fjd", "Fidschi-Dollaa" },
            { "fkp", "Pongk vun de Falkland-Enselle" },
            { "gbp", "brittesche \u00a3" },
            { "gel", "jeorjesche Lari" },
            { "ghs", "janaaesche Cedi" },
            { "gip", "jibraltaa\u2019sche Pongk" },
            { "gmd", "jambesche Dalasi" },
            { "gnf", "Jineea-Frang" },
            { "gtq", "juatemalesche Quetzal" },
            { "gyd", "Juaana-Dollaa" },
            { "hkd", "Hongkong-Dollaa" },
            { "hnl", "hondureanesche Lempira" },
            { "hrk", "krowaatesche Kuna" },
            { "htg", "haiitesche Gourde" },
            { "huf", "unjarresche Forint" },
            { "idr", "indoneesesche Ruupije" },
            { "ils", "i\u00dfraeelesche Schekel" },
            { "inr", "indesche Ruupije" },
            { "iqd", "iraakesche Denaa" },
            { "irr", "persesche Rial" },
            { "isk", "i\u00dfl\u00e4ndesche Kruhne" },
            { "jmd", "jamaikaanesche Dollaa" },
            { "jod", "Jordaanesche Dollaa" },
            { "jpy", "japaanesche Jen" },
            { "kes", "Kenjaanesche Schillinge" },
            { "kgs", "kirjiisesche Som" },
            { "khr", "kambodschaanesche Riel" },
            { "kmf", "kommooresche Frang" },
            { "kpw", "noodkorejaansche Won" },
            { "krw", "s\u00f6\u00f6dkorejaansche Won" },
            { "kwd", "kuwaitesche Denaa" },
            { "kyd", "Kaimann-Dollaa" },
            { "kzt", "kasakesche Tenge" },
            { "lak", "loaatesche Kip" },
            { "lbp", "libaneesesche Pongk" },
            { "lkr", "schrilankesche Ruupije" },
            { "lrd", "liberijaanesche Dollaa" },
            { "lsl", "lesoothesche Loti" },
            { "ltl", "littouesche Litas" },
            { "lvl", "l\u00e4ttesche Lats" },
            { "lyd", "libesche Denaa" },
            { "mad", "marrokaanesche Dirhamm" },
            { "mdl", "moldaavesche Leu" },
            { "mga", "madajaskesche Ariary" },
            { "mkd", "mazedoonesche Denaa" },
            { "mmk", "burmeesesche Kyat" },
            { "mnt", "mongjoolesche Tugrik" },
            { "mop", "makaneesesche Pataca" },
            { "mro", "mauretanesche Ouguiya (1973\u20132017)" },
            { "mru", "mauretanesche Ouguiya" },
            { "mur", "maurizjahnesche Ruupije" },
            { "mvr", "mallediivesche Rufiyaa" },
            { "mwk", "malaawesche Kwache" },
            { "mxn", "mexekaanesche Peeso" },
            { "myr", "malaisesche Ringgit" },
            { "mzm", "mosambikaanesche Metical (1980\u20132006)" },
            { "mzn", "mossambikaanesche Metical" },
            { "nad", "namiibesche Dollaa" },
            { "ngn", "nijerijaanesche Naira" },
            { "nio", "nikarajaanesche C\u00f3rdoba" },
            { "nok", "norrweejesche Kruhne" },
            { "npr", "nepaleesesche Ruupije" },
            { "nzd", "neuseel\u00e4ndesche Dollaa" },
            { "omr", "ommaanesche Rijal" },
            { "pab", "pannameesesche Balboa" },
            { "pen", "perruaanesche Sol" },
            { "pgk", "papua neujinejaanesche Kina" },
            { "php", "fillipiinesche Pesos" },
            { "pkr", "pakestaanesche Ruupije" },
            { "pln", "polnesche Z\u0142oty" },
            { "pyg", "parajuaanesche Juarani" },
            { "qar", "kataaresche Rijal" },
            { "rol", "rom\u00e4\u00e4nesche Leu (1952\u20132006)" },
            { "ron", "rom\u00e4\u00e4nesche Leu" },
            { "rsd", "s\u00e4rbesche Denaare" },
            { "rub", "russesche Ruubel" },
            { "rwf", "ruandesche Frang" },
            { "sar", "saudesche Rijal" },
            { "sbd", "solomonesche Dollaa" },
            { "scr", "seischellesche Ruupije" },
            { "sdg", "sudaneesesche Pongk" },
            { "sek", "schweedesche Kruhne" },
            { "sgd", "singjapurejaanesche Dollaa" },
            { "shp", "Zint-Hellena-Pongk" },
            { "skk", "\u00dflovaakesche Kruhne" },
            { "sll", "\u1e9ej\u00e4rra-lejoneesesche Leone" },
            { "sos", "somaalesche Schillenge" },
            { "srd", "s\u00fcrinameesesche Dollaa" },
            { "ssp", "s\u00f6dsudaneesesche Pongk" },
            { "std", "Dobra vun S\u00e3o Tom\u00e9 un Pr\u00edncipe (1977\u20132017)" },
            { "stn", "Dobra vun S\u00e3o Tom\u00e9 un Pr\u00edncipe" },
            { "svc", "asalvadorejaanesche Cosan" },
            { "syp", "s\u00fc\u00fcresche Pund" },
            { "szl", "swasil\u00e4ndesche Lilangeni" },
            { "thb", "tail\u00e4ndesche Baht" },
            { "tjs", "tadschiki\u00dftaanesche Somoni" },
            { "tmm", "turkmene\u00dftaanesche Manat (1993\u20132009)" },
            { "tmt", "turkmene\u00dftaanesche Manat" },
            { "tnd", "tuneesesche Denaa" },
            { "top", "tongjanes Pa\u02bbangache" },
            { "try", "t\u00f6rkesche Liire" },
            { "ttd", "Dollaa u\u00df Trinidad un Tob\u00e4\u00e4jo" },
            { "twd", "neu taiwaneesesche Dollaa" },
            { "tzs", "tansaanesche Schillenge" },
            { "uah", "ukraijnesche Hryvnia" },
            { "ugx", "ujandesche Schillenge" },
            { "usd", "amm\u00e4rrikaanesche Dollaa" },
            { "uyu", "urrujuwaische Peeso" },
            { "uzs", "u\u00dfbeekesche Som" },
            { "vef", "venezuelaanesche Bol\u00edvar (2008\u20132018)" },
            { "ves", "venezuelaanesche Bol\u00edvar" },
            { "vnd", "vij\u00e4tnammeesesche Dong" },
            { "vuv", "vanuatesche Vatu" },
            { "wst", "samowaanesche Tala" },
            { "xaf", "Kmmeruhner Frang" },
            { "xag", "Sellver" },
            { "xau", "Jold" },
            { "xcd", "o\u00df-karribbesche Dollaa" },
            { "xfo", "franz\u00fc\u00fcsesche Joldfranke" },
            { "xof", "Frang u\u00df de \u00c4lfebeink\u00f6\u00df" },
            { "xpd", "Palladijum" },
            { "xpf", "polineesesche Frang" },
            { "xpt", "Plaatin" },
            { "xts", "W\u00e4hrong zum Pr\u00f6\u00f6fe" },
            { "xxx", "onbikannte W\u00e4hrong" },
            { "yer", "jemenitesche Rijal" },
            { "zar", "s\u00f6daffrekaanesche Rand" },
            { "zmk", "sambesche Kwacha (1968\u20132012)" },
            { "zmw", "sambesche Kwacha" },
            { "zwd", "simbabwesche Dollaa (1980\u20132008)" },
            { "zwl", "simbabwesche Dollaa (2009)" },
        };
        return data;
    }
}
